@@ -2,6 +2,8 @@ import click
 
 from pagetools.cli.transformations.extract import extract_cli
 from pagetools.cli.transformations.regularize import regularize_cli
+from pagetools.cli.transformations.modify_text_indices import change_text_index
+
 
 @click.group()
 @click.version_option()
@@ -13,3 +15,4 @@ def cli(**kwargs):
 
 cli.add_command(extract_cli)
 cli.add_command(regularize_cli)
+cli.add_command(change_text_index)
